Page 40 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 40

Home

    revolution was expressed by the anarchist Prince
    Kropotkin in 1908:

    What we learn to-day from the study of the Great
    Revolution,... is that it was the source and origin of all the
    present communist, anarchist, and socialist

    present communist, anarchist, and socialist
    conceptions.... up till now, modern socialism has added
    absolutely nothing to the ideas that were circulating
    among the French people between 1789 and 1794, and
    which it was tried to put into practice in the year II. of
    the Republic. Modern socialism has only systematized
    those ideas and found arguments in their favor, .. . |

    anarchist,

    socialist

    present

    Indeed, the French Revolution was a source for
    communist, anarchist, and socialist conceptions;
    conceptions that, when carried to conclusion, resulted in
    the necessity of installing drainage systems to carry away
    the torrents of blood that flowed from French guillotines.
    These same "conceptions" applied during the twentieth
    century have resulted in the murder of well over one
    hundred million human beings. There is much to learn
    from the Great Revolution. Commenting on the

    nm ame. . RY. ord

    and

    socialist

    If, then, we would discover the truth about these
    great revolutionary outbreaks, we must dig down far
    below the surface, we must trace the connection between
    the mine and the explosion, between the actions of the
    people and the causes that provoked them?

    35

    The French Revolution

    That the French Revolution was a model for Socialist

    anarchist,

    Revolution, the British historian Nesta Webster wrote: